#
# spec file for package lua-lgi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Adam Mizerski <adam@mizerski.pl>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name lgi
Name:           lua-lgi
Version:        0.9.1
Release:        3.1
Summary:        Lua bindings to GObject libraries
License:        MIT
Group:          System/Libraries
Url:            https://github.com/pavouk/lgi
Source0:        https://github.com/pavouk/%{_name}/archive/%{version}.tar.gz#/%{_name}-%{version}.tar.gz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.8
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(lua)
%if 0%{?suse_version} > 1320
# Lua in openSUSE 13.2, Leap 42.x and SLE 12 does not yet provide
# Lua(API), and as such we can only depend on it in Tumbleweed,
# we need the 'branch' of lua this package was built against
# (lua_version nicely provides this info).
Requires:       Lua(API) = %{lua_version}
%endif

%description
Dynamic Lua binding to any library which is introspectable
using gobject-introspection. Allows using GObject-based libraries
directly from Lua.

%package doc
Summary:        Lua bindings to GObject libraries - documentation and samples
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description doc
Dynamic Lua binding to any library which is introspectable
using gobject-introspection. Allows using GObject-based libraries
directly from Lua.

%prep
%setup -q -n %{_name}-%{version}

%build
make %{?_smp_mflags} \
  COPTFLAGS="%{optflags}" \

%install
%make_install \
  PREFIX=%{_prefix}             \
  LUA_LIBDIR=%{lua_archdir}     \
  LUA_SHAREDIR=%{lua_noarchdir}

%files
%defattr(-,root,root)
%doc LICENSE README.md
%{lua_archdir}/%{_name}/
%{lua_noarchdir}/%{_name}.lua
%{lua_noarchdir}/%{_name}/

%files doc
%defattr(-,root,root)
%doc docs samples tools

%changelog
* Sat May 28 2016 sor.alexei@meowr.ru
- Update to version 0.9.1:
  * Marshal NULL strings as nil instead of empty strings.
    This allows use of e.g. DataInputStream:read_line() APIs.
  * Add support for arrays with lengths as struct fields.
  * Allow GLib.Variant construction for lightuserdata.
  * Fix gtop binding (certain structs could not be imported).
  * Adapt to new set of annotations in newer GLib.
  * Assorted Lua5.3 fixes, lgi is now fully Lua5.3 compatible.
  * Fix binding of Gdk.Rectangle from newer Gdk.
* Wed Sep  2 2015 dimstar@opensuse.org
- Only depend on Lua(API) in Tumbleweed: openSUSE 13.2, Leap and
  SLE12 do not yet provide this symbol.
* Thu Jul 30 2015 dimstar@opensuse.org
- Depend on Lua(API) = %%{%%lua_version}. Note: lua_version is only
  major.minor of lua (e.g 5.2, 5.3[...]). This is needed as the
  files are installed in /usr/share/lua/5.2 when built against
  lua 5.2.
* Wed Apr 29 2015 sor.alexei@meowr.ru
- Update to 0.9.0:
  * Allow defining new properties on custom GObject subclasses
    implemented using lgi.
  * Improve compatibility with locales (turkish).
  * Fix GPtrArray handling.
  * Improve behavior when running in assorted multiple-embedded and
    concurrent scenarios.
* Fri Aug 15 2014 freyes@suse.com
- new upstream package; version 0.8.0
* Tue Jan  8 2013 adam@mizerski.pl
- new package; version 0.6.2
